@@ -10,5 +10,5 @@ b1 <- mle[1]
 b2 <- mle[2]
 lam <- mle[3]
 ftemp <- fitYP3(Y=dataMat[1,], d=dataMat[2,], Z=t(dataMat[3:4,]), beta1=c(0,b1), beta2=c(0,b2), lam=lam, fun=fun)
-list(Mulam=ftemp$MuLam, Loglik=ftemp$EmpLik)
+list(Mulam=ftemp$MuLam, Loglik=ftemp$LogEmpLik)
 }
